@@ -2,8 +2,12 @@ dms_helper <- function(lon = NULL, lat = NULL) {
   stopifnot(xor(is.null(lon), is.null(lat)))
   assert(lon, c("numeric", "integer", "character"))
   assert(lat, c("numeric", "integer", "character"))
-  if (!is.null(lon)) return(pz_parse_parts_lon(scrub(lon)))
-  if (!is.null(lat)) return(pz_parse_parts_lat(scrub(lat)))
+  if (!is.null(lon)) {
+    return(pz_parse_parts_lon(scrub(lon)))
+  }
+  if (!is.null(lat)) {
+    return(pz_parse_parts_lat(scrub(lat)))
+  }
 }
 
 #' extract degree, minutes, and seconds
@@ -31,7 +35,6 @@ dms_helper <- function(lon = NULL, lat = NULL) {
 #' pz_degree(lon = 178.23423)
 #' pz_minute(lon = 178.23423)
 #' pz_second(lon = 178.23423)
-#'
 #' \dontrun{
 #' pz_degree(lat = c(45.23323, "40:25:6N", "40° 25´ 5.994 S"))
 #' pz_minute(lat = c(45.23323, "40:25:6N", "40° 25´ 5.994 S"))
@@ -82,19 +85,19 @@ print.pz <- function(x, ...) cat(x, sep = "\n")
 #' @export
 #' @rdname dms
 pz_d <- function(x) {
-  assert(x, c('integer', 'numeric'))
+  assert(x, c("integer", "numeric"))
   structure(x, class = "pz", type = "deg")
 }
 #' @export
 #' @rdname dms
 pz_m <- function(x) {
-  assert(x, c('integer', 'numeric'))
+  assert(x, c("integer", "numeric"))
   structure(x, class = "pz", type = "min")
 }
 #' @export
 #' @rdname dms
 pz_s <- function(x) {
-  assert(x, c('integer', 'numeric'))
+  assert(x, c("integer", "numeric"))
   structure(x, class = "pz", type = "sec")
 }
 #' @export
@@ -102,8 +105,16 @@ pz_s <- function(x) {
 `+.pz` <- function(e1, e2) {
   e1u <- unclass_strip_atts(e1)
   e2u <- unclass_strip_atts(e2)
-  e1 <- switch(attr(e1, "type"), deg = e1u, min  = e1u/60, sec = e1u/3600)
-  e2 <- switch(attr(e2, "type"), deg = e2u, min  = e2u/60, sec = e2u/3600)
+  e1 <- switch(attr(e1, "type"),
+    deg = e1u,
+    min = e1u / 60,
+    sec = e1u / 3600
+  )
+  e2 <- switch(attr(e2, "type"),
+    deg = e2u,
+    min = e2u / 60,
+    sec = e2u / 3600
+  )
   structure(e1 + e2, class = "pz", type = "deg")
 }
 #' @export
@@ -111,8 +122,16 @@ pz_s <- function(x) {
 `-.pz` <- function(e1, e2) {
   e1u <- unclass_strip_atts(e1)
   e2u <- unclass_strip_atts(e2)
-  e1 <- switch(attr(e1, "type"), deg = e1u, min  = e1u/60, sec = e1u/3600)
-  e2 <- switch(attr(e2, "type"), deg = e2u, min  = e2u/60, sec = e2u/3600)
+  e1 <- switch(attr(e1, "type"),
+    deg = e1u,
+    min = e1u / 60,
+    sec = e1u / 3600
+  )
+  e2 <- switch(attr(e2, "type"),
+    deg = e2u,
+    min = e2u / 60,
+    sec = e2u / 3600
+  )
   structure(e1 - e2, class = "pz", type = "deg")
 }
 #' @export
